@@ -2,6 +2,10 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+
+from .fd_alglib import *
+from .fd_cpp import *
 from .fd_numpy import *
 
+
 __all__ = [name for name in dir() if not name.startswith('_')]
